@@ -1,6 +1,6 @@
 # --
 # Copyright (C) 2001-2021 OTRS AG, https://otrs.com/
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -19,14 +19,12 @@ use Kernel::System::VariableCheck qw(:all);
 
 our @ObjectDependencies = (
     'Kernel::Config',
-    'Kernel::System::CustomerUser',
     'Kernel::System::CheckItem',
-    'Kernel::System::DB',
+    'Kernel::System::CustomerUser',
+    'Kernel::System::DateTime',
     'Kernel::System::DynamicField',
     'Kernel::System::DynamicField::Backend',
-    'Kernel::System::Email',
     'Kernel::System::Group',
-    'Kernel::System::HTMLUtils',
     'Kernel::System::JSON',
     'Kernel::System::Log',
     'Kernel::System::NotificationEvent',
@@ -35,10 +33,7 @@ our @ObjectDependencies = (
     'Kernel::System::TemplateGenerator',
     'Kernel::System::Ticket',
     'Kernel::System::Ticket::Article',
-    'Kernel::System::DateTime',
     'Kernel::System::User',
-    'Kernel::System::CheckItem',
-    'Kernel::System::Valid',
 );
 
 sub new {
@@ -257,8 +252,6 @@ sub Run {
                 next TRANSPORT;
             }
 
-            my @ValidIDs = $Kernel::OM->Get('Kernel::System::Valid')->ValidIDsGet();
-
             # check if transport is usable
             next TRANSPORT if !$TransportObject->IsUsable();
 
@@ -308,18 +301,6 @@ sub Run {
                     next BUNDLE if !$Bundle->{Recipient}->{UserID};
                 }
 
-                # Check if customer user is invalid.
-                if (
-                    $Bundle->{Recipient}->{Source}
-                    && $Bundle->{Recipient}->{Source} eq 'CustomerUser'
-                    && $Bundle->{Recipient}->{ValidID}
-                    && !grep { $Bundle->{Recipient}->{ValidID} eq $_ } @ValidIDs
-
-                    )
-                {
-                    next BUNDLE;
-                }
-
                 my $Success = $Self->_SendRecipientNotification(
                     TicketID              => $Param{Data}->{TicketID},
                     Notification          => $Bundle->{Notification},
@@ -392,24 +373,39 @@ sub _NotificationFilter {
 
     my $ArticleObject = $Kernel::OM->Get('Kernel::System::Ticket::Article');
 
-    # get not ticket related attributes
-    my $IgnoredAttributes
-        = $Kernel::OM->Get('Kernel::Config')->Get('Ticket::Event::NotificationEvent::IgnoredAttributes') || {};
-    my %IgnoredAttributesHash;
-    for my $Key ( sort keys %{$IgnoredAttributes} ) {
-        if ( IsHashRefWithData( $IgnoredAttributes->{$Key} ) ) {
-            %IgnoredAttributesHash = ( %IgnoredAttributesHash, %{ $IgnoredAttributes->{$Key} } );
-        }
-    }
-
     # get the search article fields to retrieve values for
     my %ArticleSearchableFields = $ArticleObject->ArticleSearchableFieldsList();
 
     KEY:
     for my $Key ( sort keys %{ $Notification{Data} } ) {
 
+        # TODO: This function here should be fixed to not use hardcoded attribute values!
         # ignore not ticket related attributes
-        next KEY if %IgnoredAttributesHash && $IgnoredAttributesHash{$Key};
+        next KEY if $Key eq 'Recipients';
+        next KEY if $Key eq 'SkipRecipients';
+        next KEY if $Key eq 'RecipientAgents';
+        next KEY if $Key eq 'RecipientGroups';
+        next KEY if $Key eq 'RecipientRoles';
+        next KEY if $Key eq 'TransportEmailTemplate';
+        next KEY if $Key eq 'Events';
+        next KEY if $Key eq 'ArticleSenderTypeID';
+        next KEY if $Key eq 'ArticleIsVisibleForCustomer';
+        next KEY if $Key eq 'ArticleCommunicationChannelID';
+        next KEY if $Key eq 'ArticleAttachmentInclude';
+        next KEY if $Key eq 'IsVisibleForCustomer';
+        next KEY if $Key eq 'Transports';
+        next KEY if $Key eq 'OncePerDay';
+        next KEY if $Key eq 'VisibleForAgent';
+        next KEY if $Key eq 'VisibleForAgentTooltip';
+        next KEY if $Key eq 'LanguageID';
+        next KEY if $Key eq 'SendOnOutOfOffice';
+        next KEY if $Key eq 'AgentEnabledByDefault';
+        next KEY if $Key eq 'EmailSecuritySettings';
+        next KEY if $Key eq 'EmailSigningCrypting';
+        next KEY if $Key eq 'EmailMissingCryptingKeys';
+        next KEY if $Key eq 'EmailMissingSigningKeys';
+        next KEY if $Key eq 'EmailDefaultSigningKeys';
+        next KEY if $Key eq 'NotificationType';
 
         # ignore article searchable fields
         next KEY if $ArticleSearchableFields{$Key};
